;+
; NAME: cut_lev
;
; PURPOSE: To find an appropriate cutoff level to use for testing for 
;	 the limb.
;
; METHOD: Averages over one corner and then use the size of the fluctuations 
;	to select a value above any background noise.
;
; CALLING SEQUENCE: cut=cut_lev(imgin,imgsz)
;
; PARAMETERS:	imgin	input image
;		imgsz   output of SIZE(imgin)
;
; NOTE:	This tests on the lower left 10% of the image, so if there is bad junk
;	there it may well mess things up. In particular if there are negative
;	values things can get funny, as the calculation changes.
;
;	This seems to have trouble with the ML disk images, try setting 
;	everything below about 100 to zero. This will clean up a lot of 
;	low level junk.
;
; HISTORY: Cut out as seperate routine, Feb. 4, 1993, by A. McAllister      
;	   AAP- 19-Sep-01 - corrected to handle large images 
;	  (in old version variable "a" will overflow (will be negative) 
;	  for a large size image)
;-
FUNCTION cut_lev,imgin,imgsz

;imgsz=size(image)

;a=float((fix(imgsz(1)/10)+1)*(fix(imgsz(2)/10)+1))
a=float(fix(imgsz(1)/10)+1)*float(fix(imgsz(2)/10)+1)	;AAP, changed 19-Sep-01

bk=total(imgin(0:fix(imgsz(1)/10),0:fix(imgsz(2)/10)))       ;total background
mxbk=max(imgin(1:fix(imgsz(1)/10),1:fix(imgsz(2)/10)))       ;maximum background
mnbk=min(imgin(1:fix(imgsz(1)/10),1:fix(imgsz(2)/10)))       ;minimum background
 
;check with Halpha and white light. If not alright use 1.75*avbk for those.

if min(imgin) lt 0 then begin

;print,mxbk,mnbk

  cut=(1.75*abs(mxbk-mnbk))+bk/a+1                      ;set level for finding edge

endif else begin

  cut=1.75*bk/a

endelse

return,cut


end
